@@ -1,6 +1,6 @@
 /*!
  * \file mei_node.c
- * 
+ *
  * \brief Nodal structure of the interpreter
  */
 
@@ -47,7 +47,7 @@
 #include "mei_node.h"
 
 /*----------------------------------------------------------------------------
- * External global variables declarations for the parser
+ * External global variable declarations for the parser
  *----------------------------------------------------------------------------*/
 
 #include "mei_parser_glob.h"
@@ -58,17 +58,14 @@
 extern "C" {
 #endif /* __cplusplus */
 
-
 /*============================================================================
  * Public function definitions
  *============================================================================*/
 
-
 /*----------------------------------------------------------------------------
  *
  *----------------------------------------------------------------------------*/
 
-
 mei_node_t*
 mei_const_node(const double value)
 {
@@ -85,12 +82,10 @@ mei_const_node(const double value)
     return node;
 }
 
-
 /*----------------------------------------------------------------------------
  *
  *----------------------------------------------------------------------------*/
 
-
 mei_node_t*
 mei_id_node(char *const variable)
 {
@@ -108,18 +103,16 @@ mei_id_node(char *const variable)
     node->flag = ID;
     node->ht = NULL;
     strncpy(node->type->id.i, variable, length);
-    node->type->id.c = column-length+1;
-    node->type->id.l = line;
+    node->type->id.c = mei_glob_column-length+1;
+    node->type->id.l = mei_glob_line;
 
     return node;
 }
 
-
 /*----------------------------------------------------------------------------
  *
  *----------------------------------------------------------------------------*/
 
-
 mei_node_t*
 mei_func_node(char *const function, mei_node_t *const expr)
 {
@@ -140,18 +133,16 @@ mei_func_node(char *const function, mei_node_t *const expr)
     node->ht = NULL;
     strncpy(node->type->func.name, function, length);
     node->type->func.op = expr;
-    node->type->func.c  = column-length+1;
-    node->type->func.l  = line;
+    node->type->func.c  = mei_glob_column-length+1;
+    node->type->func.l  = mei_glob_line;
 
     return node;
 }
 
-
 /*----------------------------------------------------------------------------
  *
  *----------------------------------------------------------------------------*/
 
-
 mei_node_t*
 mei_funcx_node(char *const function, const int nops, ...)
 {
@@ -199,12 +190,10 @@ mei_funcx_node(char *const function, const int nops, ...)
     return node;
 }
 
-
 /*----------------------------------------------------------------------------
  *
  *----------------------------------------------------------------------------*/
 
-
 mei_node_t*
 mei_opr_node(const int oper, const int nops, ...)
 {
@@ -266,14 +255,12 @@ mei_label_node(mei_node_t *n)
         sprintf(buff, "operator number: %d", n->type->opr.nops);
         return buff;
     }
-     
+
     BFT_MALLOC(buff, 256, char);
     sprintf(buff, "%s", " ");
     return buff;
 }
 
-
-
 /*!
  * \brief Free memory.
  *
